# Anthropic API Setup

![anthropic](https://github.com/user-attachments/assets/cf60af53-3770-4038-a256-6d931e846c00)

1. Register an Anthropic API key at https://www.anthropic.com/api

2. Select `Anthropic AI API` as ToolMate AI backend

3. Follow the dialog and enter your Anthropic AI API key.